@@ -28,6 +28,7 @@
 #include <dart/dynamics/CylinderShape.hpp>
 #include <dart/dynamics/EllipsoidShape.hpp>
 #include <dart/dynamics/FreeJoint.hpp>
+#include <dart/dynamics/HeightmapShape.hpp>
 #include <dart/dynamics/MeshShape.hpp>
 #include <dart/dynamics/PlaneShape.hpp>
 #include <dart/dynamics/PrismaticJoint.hpp>
@@ -38,11 +39,11 @@
 #include <dart/constraint/WeldJointConstraint.hpp>
 #include <dart/dynamics/WeldJoint.hpp>
 
-#include <ignition/common/Console.hh>
+#include <gz/common/Console.hh>
 #include <ignition/common/Mesh.hh>
 #include <ignition/common/MeshManager.hh>
-#include <ignition/math/eigen3/Conversions.hh>
-#include <ignition/math/Helpers.hh>
+#include <gz/math/eigen3/Conversions.hh>
+#include <gz/math/Helpers.hh>
 
 #include <sdf/Box.hh>
 #include <sdf/Collision.hh>
@@ -50,6 +51,7 @@
 #include <sdf/Cylinder.hh>
 #include <sdf/Ellipsoid.hh>
 #include <sdf/Geometry.hh>
+#include <sdf/Heightmap.hh>
 #include <sdf/Joint.hh>
 #include <sdf/JointAxis.hh>
 #include <sdf/Link.hh>
@@ -126,20 +128,6 @@ static void CopyStandardJointAxisProperties(
     const int _index, Properties &_properties,
     const ::sdf::JointAxis *_sdfAxis)
 {
-#ifndef _WIN32
-# pragma GCC diagnostic push
-# pragma GCC diagnostic ignored "-Wdeprecated-declarations"
-#else
-# pragma warning(push)
-# pragma warning(disable: 4996)
-#endif
-  // TODO(anyone): stop using this deprecated function
-  _properties.mInitialPositions[_index] = _sdfAxis->InitialPosition();
-#ifndef _WIN32
-# pragma GCC diagnostic pop
-#else
-# pragma warning(pop)
-#endif
   _properties.mDampingCoefficients[_index] = _sdfAxis->Damping();
   _properties.mFrictions[_index] = _sdfAxis->Friction();
   _properties.mRestPositions[_index] = _sdfAxis->SpringReference();
@@ -176,7 +164,7 @@ static Eigen::Vector3d ConvertJointAxis(
   // Error while Resolving xyz. Fallback sdformat 1.6 behavior but treat
   // xyz_expressed_in = "__model__" as the old use_parent_model_frame
 
-  const Eigen::Vector3d axis = ignition::math::eigen3::convert(_sdfAxis->Xyz());
+  const Eigen::Vector3d axis = math::eigen3::convert(_sdfAxis->Xyz());
 
   if (_sdfAxis->XyzExpressedIn().empty())
     return axis;
@@ -314,6 +302,15 @@ static ShapeAndTransform ConstructPlane(
           Eigen::Vector3d(planeDim, planeDim, planeDim)), tf};
 }
 
+/////////////////////////////////////////////////
+static ShapeAndTransform ConstructHeightmap(
+    const ::sdf::Heightmap & /*_heightmap*/)
+{
+  ignerr << "Heightmap construction from an SDF has not been implemented yet "
+         << "for dartsim.\n";
+  return {nullptr};
+}
+
 /////////////////////////////////////////////////
 static ShapeAndTransform ConstructMesh(
     const ::sdf::Mesh & /*_mesh*/)
@@ -362,6 +359,8 @@ static ShapeAndTransform ConstructGeometry(
     return ConstructPlane(*_geometry.PlaneShape());
   else if (_geometry.MeshShape())
     return ConstructMesh(*_geometry.MeshShape());
+  else if (_geometry.HeightmapShape())
+    return ConstructHeightmap(*_geometry.HeightmapShape());
 
   return {nullptr};
 }
@@ -396,7 +395,7 @@ Identity SDFFeatures::ConstructSdfWorld(
 
   const dart::simulation::WorldPtr &world = this->worlds.at(worldID);
 
-  world->setGravity(ignition::math::eigen3::convert(_sdfWorld.Gravity()));
+  world->setGravity(math::eigen3::convert(_sdfWorld.Gravity()));
 
   // TODO(MXG): Add a Physics class to the SDFormat DOM and then parse that
   // information here. For now, we'll just use dartsim's default physics
@@ -589,18 +588,10 @@ Identity SDFFeatures::ConstructSdfLink(
   dart::dynamics::BodyNode::Properties bodyProperties;
   bodyProperties.mName = _sdfLink.Name();
 
-  const ignition::math::Inertiald &sdfInertia = _sdfLink.Inertial();
+  const math::Inertiald &sdfInertia = _sdfLink.Inertial();
   bodyProperties.mInertia.setMass(sdfInertia.MassMatrix().Mass());
 
-  // TODO(addisu) Resolve the pose of inertials when frame information is
-  // availabile for ignition::math::Inertial
-  const Eigen::Matrix3d R_inertial{
-        math::eigen3::convert(sdfInertia.Pose().Rot())};
-
-  const Eigen::Matrix3d I_link =
-      R_inertial
-      * math::eigen3::convert(sdfInertia.Moi())
-      * R_inertial.inverse();
+  const Eigen::Matrix3d I_link = math::eigen3::convert(sdfInertia.Moi());
 
   bodyProperties.mInertia.setMoment(I_link);
 
@@ -609,6 +600,8 @@ Identity SDFFeatures::ConstructSdfLink(
 
   bodyProperties.mInertia.setLocalCOM(localCom);
 
+  bodyProperties.mGravityMode = _sdfLink.EnableGravity();
+
   dart::dynamics::FreeJoint::Properties jointProperties;
   jointProperties.mName = bodyProperties.mName + "_FreeJoint";
   // TODO(MXG): Consider adding a UUID to this joint name in order to avoid any
@@ -641,8 +634,7 @@ Identity SDFFeatures::ConstructSdfLink(
   const std::string fullName = ::sdf::JoinName(
       world->getName(),
       ::sdf::JoinName(modelInfo.model->getName(), bn->getName()));
-  const std::size_t linkID = this->AddLink(bn, fullName, _modelID);
-  this->AddJoint(joint);
+  const std::size_t linkID = this->AddLink(bn, fullName, _modelID, sdfInertia);
 
   auto linkIdentity = this->GenerateIdentity(linkID, this->links.at(linkID));
 
@@ -818,7 +810,7 @@ Identity SDFFeatures::ConstructSdfCollision(
     }
     if (odeFriction->HasElement("slip1"))
     {
-      aspect->setSlipCompliance(odeFriction->Get<double>("slip1"));
+      aspect->setPrimarySlipCompliance(odeFriction->Get<double>("slip1"));
     }
     if (odeFriction->HasElement("slip2"))
     {
@@ -936,7 +928,7 @@ Identity SDFFeatures::ConstructSdfVisual(
   // intended for the physics?
   if (_visual.Material())
   {
-    const ignition::math::Color &color = _visual.Material()->Ambient();
+    const math::Color &color = _visual.Material()->Ambient();
     node->getVisualAspect()->setColor(
           Eigen::Vector4d(color.R(), color.G(), color.B(), color.A()));
   }
@@ -1020,10 +1012,11 @@ Identity SDFFeatures::ConstructSdfJoint(
 
   {
     auto childsParentJoint = _child->getParentJoint();
+    std::string parentName = worldParent? "world" : _parent->getName();
     if (childsParentJoint->getType() != "FreeJoint")
     {
       ignerr << "Asked to create a joint between links "
-             << "[" << _parent->getName() << "] as parent and ["
+             << "[" << parentName << "] as parent and ["
              << _child->getName() << "] as child, but the child link already "
              << "has a parent joint of type [" << childsParentJoint->getType()
              << "].\n";
@@ -1033,7 +1026,7 @@ Identity SDFFeatures::ConstructSdfJoint(
     {
       // TODO(MXG): Add support for non-tree graph structures
       ignerr << "Asked to create a closed kinematic chain between links "
-             << "[" << _parent->getName() << "] and [" << _child->getName()
+             << "[" << parentName << "] and [" << _child->getName()
              << "], but that is not supported by the dartsim wrapper yet.\n";
       return this->GenerateInvalidId();
     }
@@ -1108,38 +1101,17 @@ Identity SDFFeatures::ConstructSdfJoint(
 
   joint->setName(_sdfJoint.Name());
 
-  // When initial positions are provided for joints, we need to correct the
-  // parent transform:
   const Eigen::Isometry3d child_T_postjoint = T_child.inverse() * T_joint;
   const Eigen::Isometry3d parent_T_prejoint_init = T_parent.inverse() * T_joint;
   joint->setTransformFromParentBodyNode(parent_T_prejoint_init);
   joint->setTransformFromChildBodyNode(child_T_postjoint);
 
-  // This is the transform inside the joint produced by whatever the current
-  // joint position happens to be.
-  const Eigen::Isometry3d T_child_parent_postjoint =
-      _parent ? _child->getTransform(_parent) : _child->getTransform();
-
-  const Eigen::Isometry3d prejoint_T_postjoint =
-      parent_T_prejoint_init.inverse()
-      * T_child_parent_postjoint
-      * child_T_postjoint;
-
-  // This is the corrected transform needed to get the child link to its
-  // correct pose (as specified by the loaded SDF) for the current initial
-  // position
-  const Eigen::Isometry3d T_parent_postjoint =
-      _parent ? _parent->getWorldTransform() : Eigen::Isometry3d::Identity();
-
-  const Eigen::Isometry3d parent_T_prejoint_final =
-      T_parent_postjoint.inverse()
-      * T_child
-      * child_T_postjoint
-      * prejoint_T_postjoint.inverse();
-
-  joint->setTransformFromParentBodyNode(parent_T_prejoint_final);
-
   const std::size_t jointID = this->AddJoint(joint);
+  // Increment BodyNode version since the child could be moved to a new skeleton
+  // when a joint is created.
+  // TODO(azeey) Remove incrementVersion once DART has been updated to
+  // internally increment the BodyNode's version after Joint::moveTo.
+  _child->incrementVersion();
 
   return this->GenerateIdentity(jointID, this->joints.at(jointID));
 }
