@@ -28,21 +28,22 @@
 
 #include <tuple>
 
-#include <ignition/plugin/Loader.hh>
+#include <gz/plugin/Loader.hh>
 
-#include <ignition/physics/GetEntities.hh>
-#include <ignition/physics/Joint.hh>
-#include <ignition/physics/RequestEngine.hh>
+#include <ignition/physics/FrameSemantics.hh>
+#include <gz/physics/GetEntities.hh>
+#include <gz/physics/Joint.hh>
+#include <gz/physics/RequestEngine.hh>
 #include <ignition/physics/RevoluteJoint.hh>
 
 #include <ignition/physics/sdf/ConstructCollision.hh>
-#include <ignition/physics/sdf/ConstructJoint.hh>
-#include <ignition/physics/sdf/ConstructLink.hh>
-#include <ignition/physics/sdf/ConstructModel.hh>
+#include <gz/physics/sdf/ConstructJoint.hh>
+#include <gz/physics/sdf/ConstructLink.hh>
+#include <gz/physics/sdf/ConstructModel.hh>
 #include <ignition/physics/sdf/ConstructNestedModel.hh>
-#include <ignition/physics/sdf/ConstructWorld.hh>
+#include <gz/physics/sdf/ConstructWorld.hh>
 
-#include <ignition/physics/dartsim/World.hh>
+#include <gz/physics/dartsim/World.hh>
 
 #include <sdf/Collision.hh>
 #include <sdf/Joint.hh>
@@ -53,35 +54,38 @@
 
 #include <test/Utils.hh>
 
-struct TestFeatureList : ignition::physics::FeatureList<
-    ignition::physics::GetEntities,
-    ignition::physics::GetBasicJointState,
-    ignition::physics::SetBasicJointState,
-    ignition::physics::dartsim::RetrieveWorld,
+using namespace ignition;
+
+struct TestFeatureList : physics::FeatureList<
+    physics::GetEntities,
+    physics::GetBasicJointState,
+    physics::SetBasicJointState,
+    ignition::physics::LinkFrameSemantics,
+    physics::dartsim::RetrieveWorld,
     ignition::physics::sdf::ConstructSdfCollision,
-    ignition::physics::sdf::ConstructSdfJoint,
-    ignition::physics::sdf::ConstructSdfLink,
-    ignition::physics::sdf::ConstructSdfModel,
+    physics::sdf::ConstructSdfJoint,
+    physics::sdf::ConstructSdfLink,
+    physics::sdf::ConstructSdfModel,
     ignition::physics::sdf::ConstructSdfNestedModel,
-    ignition::physics::sdf::ConstructSdfWorld
+    physics::sdf::ConstructSdfWorld
 > { };
 
-using World = ignition::physics::World3d<TestFeatureList>;
-using WorldPtr = ignition::physics::World3dPtr<TestFeatureList>;
+using World = physics::World3d<TestFeatureList>;
+using WorldPtr = physics::World3dPtr<TestFeatureList>;
 using ModelPtr = ignition::physics::Model3dPtr<TestFeatureList>;
 using LinkPtr = ignition::physics::Link3dPtr<TestFeatureList>;
 
 /////////////////////////////////////////////////
 auto LoadEngine()
 {
-  ignition::plugin::Loader loader;
+  plugin::Loader loader;
   loader.LoadLib(dartsim_plugin_LIB);
 
-  ignition::plugin::PluginPtr dartsim =
+  plugin::PluginPtr dartsim =
       loader.Instantiate("ignition::physics::dartsim::Plugin");
 
   auto engine =
-      ignition::physics::RequestEngine3d<TestFeatureList>::From(dartsim);
+      physics::RequestEngine3d<TestFeatureList>::From(dartsim);
   return engine;
 }
 
@@ -100,7 +104,7 @@ WorldPtr LoadWorldWhole(const std::string &_world)
   sdf::Root root;
   const sdf::Errors &errors = root.Load(_world);
   EXPECT_EQ(0u, errors.size());
-  for (const auto error : errors) {
+  for (const auto & error : errors) {
     std::cout << error << std::endl;
   }
 
@@ -315,7 +319,7 @@ TEST_P(SDFFeatures_TEST, CheckDartsimData)
   dart::simulation::WorldPtr dartWorld = world->GetDartsimWorld();
   ASSERT_NE(nullptr, dartWorld);
 
-  ASSERT_EQ(6u, dartWorld->getNumSkeletons());
+  ASSERT_EQ(7u, dartWorld->getNumSkeletons());
 
   const dart::dynamics::SkeletonPtr skeleton = dartWorld->getSkeleton(1);
   ASSERT_NE(nullptr, skeleton);
@@ -323,12 +327,10 @@ TEST_P(SDFFeatures_TEST, CheckDartsimData)
   ASSERT_EQ(3u, skeleton->getNumBodyNodes());
 
   auto verify = [](const dart::dynamics::DegreeOfFreedom * dof,
-                   double initialPos, double damping, double friction,
+                   double damping, double friction,
                    double springRest, double stiffness, double lower,
                    double upper, double maxForce, double maxVelocity)
   {
-    EXPECT_DOUBLE_EQ(initialPos, dof->getPosition());
-    EXPECT_DOUBLE_EQ(initialPos, dof->getInitialPosition());
     EXPECT_DOUBLE_EQ(damping, dof->getDampingCoefficient());
     EXPECT_DOUBLE_EQ(friction, dof->getCoulombFriction());
     EXPECT_DOUBLE_EQ(springRest, dof->getRestPosition());
@@ -344,12 +346,12 @@ TEST_P(SDFFeatures_TEST, CheckDartsimData)
   // Test that things were parsed correctly. These values are either stated or
   // implied in the test.world SDF file.
   verify(skeleton->getJoint(1)->getDof(0),
-         1.5706796, 3.0, 0.0, 0.0, 0.0, -1e16, 1e16,
+         3.0, 0.0, 0.0, 0.0, -1e16, 1e16,
          std::numeric_limits<double>::infinity(),
          std::numeric_limits<double>::infinity());
 
   verify(skeleton->getJoint(2)->getDof(0),
-         -0.429462, 3.0, 0.0, 0.0, 0.0, -1e16, 1e16,
+         3.0, 0.0, 0.0, 0.0, -1e16, 1e16,
          std::numeric_limits<double>::infinity(),
          std::numeric_limits<double>::infinity());
 
@@ -538,7 +540,7 @@ TEST_P(SDFFeatures_TEST, WorldWithNestedModel)
   WorldPtr world =
       this->LoadWorld(TEST_WORLD_DIR "/world_with_nested_model.sdf");
   ASSERT_NE(nullptr, world);
-  EXPECT_EQ(4u, world->GetModelCount());
+  EXPECT_EQ(2u, world->GetModelCount());
 
   dart::simulation::WorldPtr dartWorld = world->GetDartsimWorld();
   ASSERT_NE(nullptr, dartWorld);
@@ -597,7 +599,7 @@ TEST_P(SDFFeatures_TEST, WorldWithNestedModelJointToWorld)
   WorldPtr world = this->LoadWorld(
       TEST_WORLD_DIR "/world_with_nested_model_joint_to_world.sdf");
   ASSERT_NE(nullptr, world);
-  EXPECT_EQ(2u, world->GetModelCount());
+  EXPECT_EQ(1u, world->GetModelCount());
 
   dart::simulation::WorldPtr dartWorld = world->GetDartsimWorld();
   ASSERT_NE(nullptr, dartWorld);
@@ -661,6 +663,56 @@ TEST_P(SDFFeatures_TEST, FallbackToFixedJoint)
   }
 }
 
+/////////////////////////////////////////////////
+// Check that joints between links in different models work as expected
+TEST_P(SDFFeatures_TEST, JointsAcrossNestedModels)
+{
+  WorldPtr world = this->LoadWorld(
+      TEST_WORLD_DIR "/joint_across_nested_models.sdf");
+  ASSERT_NE(nullptr, world);
+
+  dart::simulation::WorldPtr dartWorld = world->GetDartsimWorld();
+  ASSERT_NE(nullptr, dartWorld);
+
+  auto checkModel = [&world](const std::string &_modelName){
+    SCOPED_TRACE("checkModel " + _modelName);
+    // check top level model
+    auto parentModel = world->GetModel(_modelName);
+    ASSERT_NE(nullptr, parentModel);
+
+    auto link1 = parentModel->GetLink("link1");
+    ASSERT_NE(nullptr, link1);
+
+    auto nestedModel = parentModel->GetNestedModel("nested_model");
+    ASSERT_NE(nullptr, nestedModel);
+
+    auto link2 = nestedModel->GetLink("link2");
+    ASSERT_NE(nullptr, link2);
+
+    Eigen::Vector3d link1Pos =
+        link1->FrameDataRelativeToWorld().pose.translation();
+    Eigen::Vector3d link2Pos =
+        link2->FrameDataRelativeToWorld().pose.translation();
+    EXPECT_NEAR(0.25, link1Pos.z(), 1e-6);
+    EXPECT_NEAR(0.25, link2Pos.z(), 1e-6);
+  };
+
+  {
+    SCOPED_TRACE("Before step");
+    checkModel("M1");
+    checkModel("M2");
+  }
+  for (int i = 0; i < 1000; ++i)
+  {
+    dartWorld->step();
+  }
+  {
+    SCOPED_TRACE("After step");
+    checkModel("M1");
+    checkModel("M2");
+  }
+}
+
 /////////////////////////////////////////////////
 class SDFFeatures_FrameSemantics: public SDFFeatures_TEST
 {
@@ -699,7 +751,7 @@ TEST_P(SDFFeatures_FrameSemantics, LinkRelativeTo)
   dartWorld->step();
 
   // Step once and check
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       expWorldPose, link2->getWorldTransform(), 1e-3));
 }
 
@@ -730,13 +782,13 @@ TEST_P(SDFFeatures_FrameSemantics, CollisionRelativeTo)
   Eigen::Isometry3d expPose;
   expPose = Eigen::Translation3d(0, 0, -1);
 
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       expPose, collision->getRelativeTransform(), 1e-5));
 
   // Step once and check, the relative pose should still be the same
   dartWorld->step();
 
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       expPose, collision->getRelativeTransform(), 1e-5));
 }
 
@@ -767,7 +819,7 @@ TEST_P(SDFFeatures_FrameSemantics, ExplicitFramesWithLinks)
   Eigen::Isometry3d link1ExpPose;
   link1ExpPose = Eigen::Translation3d(1, 0, 1);
 
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       link1ExpPose, link1->getWorldTransform(), 1e-5));
 
   // Expect the world pose of L2 to be the same as the world pose of F2, which
@@ -775,15 +827,15 @@ TEST_P(SDFFeatures_FrameSemantics, ExplicitFramesWithLinks)
   Eigen::Isometry3d link2ExpPose;
   link2ExpPose = Eigen::Translation3d(1, 0, 0);
 
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       link2ExpPose, link2->getWorldTransform(), 1e-5));
 
   // Step once and check
   dartWorld->step();
 
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       link1ExpPose, link1->getWorldTransform(), 1e-5));
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       link2ExpPose, link2->getWorldTransform(), 1e-5));
 }
 
@@ -814,13 +866,13 @@ TEST_P(SDFFeatures_FrameSemantics, ExplicitFramesWithCollision)
   Eigen::Isometry3d expPose;
   expPose = Eigen::Translation3d(0, 0, 1);
 
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       expPose, collision->getRelativeTransform(), 1e-5));
 
   // Step once and check
   dartWorld->step();
 
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       expPose, collision->getRelativeTransform(), 1e-5));
 }
 
@@ -851,13 +903,13 @@ TEST_P(SDFFeatures_FrameSemantics, ExplicitWorldFrames)
 
   // Since we can't get the skeleton's world transform, we use the world
   // transform of L1 which is at the origin of the model frame.
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       expPose, link1->getWorldTransform(), 1e-5));
 
   // Step once and check
   dartWorld->step();
 
-  EXPECT_TRUE(ignition::physics::test::Equal(
+  EXPECT_TRUE(physics::test::Equal(
       expPose, link1->getWorldTransform(), 1e-5));
 }
 
