@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2019 Open Source Robotics Foundation
  *
- * Licensed under the Apache License, Version 3.0 (the "License");
+ * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
@@ -25,27 +25,27 @@
 
 #include <iostream>
 
-#include <ignition/physics/FindFeatures.hh>
-#include <ignition/plugin/Loader.hh>
-#include <ignition/physics/RequestEngine.hh>
+#include <gz/physics/FindFeatures.hh>
+#include <gz/plugin/Loader.hh>
+#include <gz/physics/RequestEngine.hh>
 
-#include <ignition/math/eigen3/Conversions.hh>
+#include <gz/math/eigen3/Conversions.hh>
 
 // Features
-#include <ignition/physics/ConstructEmpty.hh>
-#include <ignition/physics/ForwardStep.hh>
-#include <ignition/physics/FrameSemantics.hh>
-#include <ignition/physics/FreeJoint.hh>
-#include <ignition/physics/FixedJoint.hh>
-#include <ignition/physics/GetEntities.hh>
-#include <ignition/physics/Joint.hh>
-#include <ignition/physics/Link.hh>
-#include <ignition/physics/Shape.hh>
-#include <ignition/physics/RevoluteJoint.hh>
-#include <ignition/physics/dartsim/World.hh>
-#include <ignition/physics/sdf/ConstructModel.hh>
-#include <ignition/physics/sdf/ConstructWorld.hh>
-#include <ignition/physics/sdf/ConstructLink.hh>
+#include <gz/physics/ConstructEmpty.hh>
+#include <gz/physics/ForwardStep.hh>
+#include <gz/physics/FrameSemantics.hh>
+#include <gz/physics/FreeJoint.hh>
+#include <gz/physics/FixedJoint.hh>
+#include <gz/physics/GetEntities.hh>
+#include <gz/physics/Joint.hh>
+#include <gz/physics/Link.hh>
+#include <gz/physics/Shape.hh>
+#include <gz/physics/RevoluteJoint.hh>
+#include <gz/physics/dartsim/World.hh>
+#include <gz/physics/sdf/ConstructModel.hh>
+#include <gz/physics/sdf/ConstructWorld.hh>
+#include <gz/physics/sdf/ConstructLink.hh>
 
 #include <sdf/Model.hh>
 #include <sdf/Root.hh>
@@ -54,9 +54,9 @@
 #include "test/Utils.hh"
 #include "ShapeFeatures.hh"
 
-using namespace ignition;
+using namespace gz;
 
-using TestFeatureList = ignition::physics::FeatureList<
+using TestFeatureList = physics::FeatureList<
   physics::dartsim::RetrieveWorld,
   physics::AttachFixedJointFeature,
   physics::AddLinkExternalForceTorque,
@@ -70,6 +70,7 @@ using TestFeatureList = ignition::physics::FeatureList<
   physics::RevoluteJointCast,
   physics::SetJointVelocityCommandFeature,
 #if DART_VERSION_AT_LEAST(6, 10, 0)
+  physics::GetShapeFrictionPyramidSlipCompliance,
   physics::SetShapeFrictionPyramidSlipCompliance,
 #endif
   physics::sdf::ConstructSdfModel,
@@ -84,38 +85,19 @@ class ShapeFeaturesFixture : public ::testing::Test
 {
   protected: void SetUp() override
   {
-    ignition::plugin::Loader loader;
+    plugin::Loader loader;
     loader.LoadLib(dartsim_plugin_LIB);
 
-    ignition::plugin::PluginPtr dartsim =
+    plugin::PluginPtr dartsim =
         loader.Instantiate("ignition::physics::dartsim::Plugin");
 
     this->engine =
-        ignition::physics::RequestEngine3d<TestFeatureList>::From(dartsim);
+        physics::RequestEngine3d<TestFeatureList>::From(dartsim);
     ASSERT_NE(nullptr, this->engine);
   }
   protected: TestEnginePtr engine;
 };
 
-TestWorldPtr LoadWorld(
-    const TestEnginePtr &_engine,
-    const std::string &_sdfFile,
-    const Eigen::Vector3d &_gravity = Eigen::Vector3d{0, 0, -9.8})
-{
-  sdf::Root root;
-  const sdf::Errors errors = root.Load(_sdfFile);
-  EXPECT_TRUE(errors.empty());
-  const sdf::World *sdfWorld = root.WorldByIndex(0);
-  // Make a copy of the world so we can set the gravity property
-  // TODO(addisu) Add a world property feature to set gravity instead of this
-  // hack
-  sdf::World worldCopy;
-  worldCopy.Load(sdfWorld->Element());
-
-  worldCopy.SetGravity(math::eigen3::convert(_gravity));
-  return _engine->ConstructWorld(worldCopy);
-}
-
 // A predicate-formatter for asserting that two vectors are approximately equal.
 class AssertVectorApprox
 {
@@ -127,7 +109,7 @@ class AssertVectorApprox
               const char *_mExpr, const char *_nExpr, Eigen::Vector3d _m,
               Eigen::Vector3d _n)
   {
-    if (ignition::physics::test::Equal(_m, _n, this->tol))
+    if (physics::test::Equal(_m, _n, this->tol))
       return ::testing::AssertionSuccess();
 
     return ::testing::AssertionFailure()
@@ -159,9 +141,9 @@ TEST_F(ShapeFeaturesFixture, PrimarySlipCompliance)
 
   AssertVectorApprox vectorPredicate(1e-4);
 
-  ignition::physics::ForwardStep::Input input;
-  ignition::physics::ForwardStep::State state;
-  ignition::physics::ForwardStep::Output output;
+  physics::ForwardStep::Input input;
+  physics::ForwardStep::State state;
+  physics::ForwardStep::Output output;
 
   // Check that link is at rest
   {
@@ -180,7 +162,11 @@ TEST_F(ShapeFeaturesFixture, PrimarySlipCompliance)
   const Eigen::Vector3d cmdForce{1, 0, 0};
   const double primarySlip = 0.5;
 
+  // expect 0.0 initial slip
+  EXPECT_DOUBLE_EQ(0.0, boxShape->GetPrimarySlipCompliance());
+
   boxShape->SetPrimarySlipCompliance(primarySlip);
+  EXPECT_DOUBLE_EQ(primarySlip, boxShape->GetPrimarySlipCompliance());
 
   const std::size_t numSteps = 10000;
   for (std::size_t i = 0; i < numSteps; ++i)
@@ -218,9 +204,9 @@ TEST_F(ShapeFeaturesFixture, SecondarySlipCompliance)
 
   AssertVectorApprox vectorPredicate(1e-4);
 
-  ignition::physics::ForwardStep::Input input;
-  ignition::physics::ForwardStep::State state;
-  ignition::physics::ForwardStep::Output output;
+  physics::ForwardStep::Input input;
+  physics::ForwardStep::State state;
+  physics::ForwardStep::Output output;
 
   // Check that link is at rest
   {
@@ -239,7 +225,11 @@ TEST_F(ShapeFeaturesFixture, SecondarySlipCompliance)
   const Eigen::Vector3d cmdForce{0, 1, 0};
   const double secondarySlip = 0.25;
 
+  // expect 0.0 initial slip
+  EXPECT_DOUBLE_EQ(0.0, boxShape->GetSecondarySlipCompliance());
+
   boxShape->SetSecondarySlipCompliance(secondarySlip);
+  EXPECT_DOUBLE_EQ(secondarySlip, boxShape->GetSecondarySlipCompliance());
 
   const std::size_t numSteps = 10000;
   for (std::size_t i = 0; i < numSteps; ++i)
